@@ -22,7 +22,7 @@ class AsyncLiqPay(LiqPayBase):
         url: str,
         params: Optional[dict] = None
     ):
-        params = self._prepare_params(params)
+        params = self._prepare_params(params or {})
 
         json_encoded_params = json.dumps(params)
         private_key = self._private_key
